@@ -60,29 +60,22 @@ double ext_kalmanfilter(size_t t, size_t regime,
 	void (*func_jacob_dynam)(const double, const double, size_t, const gsl_vector *, 
 		double *, size_t,const gsl_vector *, 
 		void (*g)(double, size_t, double *, const gsl_vector *, gsl_matrix *), gsl_matrix *),
+	gsl_vector *eta_pred,
+	gsl_matrix *error_cov_pred,
 	gsl_vector *eta_t_plus_1, gsl_matrix *error_cov_t_plus_1, 
 	gsl_vector *innov_v, gsl_matrix *inv_innov_cov,
-	bool isFirstTime);
+	gsl_matrix *innov_cov,
+	bool isFirstTime, bool isForReturn);
 
 size_t find_miss_data(const gsl_vector *y, gsl_vector *non_miss);
 
-double ext_kalmanfilter_smoother(size_t t, size_t regime, 
-	gsl_vector *eta_t,  gsl_matrix *error_cov_t,
-	const gsl_vector *y_t_plus_1,const gsl_vector *co_variate, const double *y_time,
-	const gsl_matrix *eta_noise_cov, const gsl_matrix *y_noise_cov, 
-	double *params,size_t num_func_param, 
-	bool isContinuousTime, 
-	void (*func_measure)(size_t, size_t, double *, const gsl_vector *, const gsl_vector *, gsl_matrix *, gsl_vector *), 
-	void (*func_dx_dt)(double, size_t, const gsl_vector *, double *, size_t, const gsl_vector *, gsl_vector *), 
-	void (*func_dP_dt)(double, size_t, const gsl_vector *, double *, size_t, const gsl_vector *, gsl_vector *), 
-	void (*func_dF_dx)(double, size_t, double *, const gsl_vector *, gsl_matrix *), 
-	void (*func_dynam)(const double, const double, size_t, const gsl_vector *,double *, size_t, const gsl_vector *, void (*g)(double, size_t, const gsl_vector *, double *, size_t, const gsl_vector *, gsl_vector *),gsl_vector *), 
-	void (*func_jacob_dynam)(const double, const double, size_t, const gsl_vector *, 
-		double *, size_t,const gsl_vector *, 
-		void (*g)(double, size_t, double *, const gsl_vector *, gsl_matrix *),
-		gsl_matrix *),
-	gsl_vector *eta_pred, gsl_matrix *error_cov_pred, gsl_vector *eta_t_plus_1, gsl_matrix *error_cov_t_plus_1, 
-	gsl_vector *innov_v, gsl_matrix *inv_innov_cov, gsl_matrix *innov_cov, bool isFirstTime);
+void filter_vector(const gsl_vector *y, const gsl_vector *y_ind, gsl_vector *ysmall);
+
+void filter_matrix_rows(const gsl_matrix *X, const gsl_vector *y_ind, gsl_matrix *Xsmall);
+
+void filter_matrix_cols(const gsl_matrix *X, const gsl_vector *y_ind, gsl_matrix *Xsmall);
+
+void filter_matrix_rows_cols(const gsl_matrix *X, const gsl_vector *y_ind, gsl_matrix *Xsmall);
 
 
 #endif
